@@ -11,15 +11,6 @@ from .. import default
 from typing import TYPE_CHECKING, Any, Iterable, Type
 from ormlambda.sql.comparer import Comparer, ComparerCluster
 
-if TYPE_CHECKING:
-    from ormlambda.sql.functions.interface import IFunction
-    from ormlambda.sql.types import ColumnType
-    from test.test_clause_info import ST_Contains
-    from ormlambda import JoinSelector
-    from ormlambda.sql.column.column import Column
-    from mysql import connector
-    from ormlambda.dialects.mysql.clauses import ST_AsText
-
 from .types import (
     _NumericType,
     _NumericCommonType,
@@ -64,6 +55,14 @@ from .repository import MySQLRepository
 
 
 if TYPE_CHECKING:
+    from ormlambda.sql.functions.interface import IFunction
+    from ormlambda.sql.types import ColumnType
+    from test.test_clause_info import ST_Contains
+    from ormlambda import JoinSelector
+    from ormlambda.sql.column.column import Column
+    from mysql import connector
+    from ormlambda.dialects.mysql.clauses import ST_AsText
+
     from ormlambda.sql.clauses import (
         Select,
         Insert,
@@ -101,15 +100,12 @@ class MySQLCompiler(compiler.SQLCompiler):
     render_table_with_column_in_update_from = True
     """Overridden from base SQLCompiler value"""
 
-    def visit_table(self, table: Table):
-        return ClauseInfo(table=table, dialect=self.dialect).query(dialect=self.dialect)
-
     def visit_table_proxy(self, table: TableProxy, **kw) -> str:
         param = {
-            "table": None,
-            "column": table._table_class.__table_name__,
-            "dialect": self.dialect,
+            "table": table._table_class,
+            "column": None,
             "alias_clause": alias if (alias := table.get_table_chain()) else None,
+            "dialect": self.dialect,
             **kw,
         }
         return ClauseInfo(**param).query(dialect=self.dialect)
@@ -132,7 +128,7 @@ class MySQLCompiler(compiler.SQLCompiler):
         params = {
             "table": column.table,
             "column": column,
-            "alias_table": alias_table if alias_table else "{table}",
+            "alias_table": alias_table,
             "alias_clause": column.alias or "{column}",
             "dtype": column._column.dtype,
             "dialect": self.dialect,
@@ -216,9 +212,9 @@ class MySQLCompiler(compiler.SQLCompiler):
         rt = join.rcon.table
         rtable = TableProxy(table_class=rt, path=join.rcon.path)
 
-        from_clause = rtable.compile(self.dialect, alias_clause=join.alias).string
+        from_clause = rtable.compile(self.dialect, alias_table=join.alias, first_apperance=True).string
         left_table_clause = join.lcon.compile(self.dialect, alias_clause=None).string
-        right_table_clause = join.rcon.compile(self.dialect, alias_table=join.alias, alias_clause=None).string
+        right_table_clause = join.rcon.compile(self.dialect, alias_clause=None).string
         list_ = [
             join._by.value,  # inner join
             from_clause,
@@ -242,9 +238,11 @@ class MySQLCompiler(compiler.SQLCompiler):
         columns = ClauseInfo.join_clauses(select.columns, sep, dialect=self.dialect, **params)
 
         from_ = ClauseInfo(
-            select._table,
-            None,
+            table=select._table,
+            column=None,
+            alias_table="{table}",
             dialect=self.dialect,
+            first_apperance=True,
         ).query(self.dialect)
 
         return f"SELECT{sep}{columns}{sep}FROM {from_}"
@@ -467,7 +465,7 @@ class MySQLCompiler(compiler.SQLCompiler):
         else:
             column = count.column
 
-        return ClauseInfo.concat_alias_and_column(f"COUNT({column})", count.alias)
+        return ClauseInfo.concat_clause_with_his_alias(f"COUNT({column})", count.alias)
 
     def visit_order(self, order: Order, **kw) -> str:
         ORDER = "ORDER BY"
@@ -514,10 +512,10 @@ class MySQLCompiler(compiler.SQLCompiler):
         clause_info = ClauseInfo(
             table=None,
             column=f"CONCAT({', '.join(columns)})",
-            alias_clause=concat.alias,
             dialect=self.dialect,
+            literal=True
         )
-        return clause_info.query(self.dialect)
+        return f"{clause_info.query(self.dialect)} AS {ClauseInfo.wrapped_with_quotes(concat.alias)}" 
 
     def visit_max(self, obj: Max, **kw) -> str:
         return self._compile_aggregate_method("MAX", obj, **kw)
@@ -546,7 +544,7 @@ class MySQLCompiler(compiler.SQLCompiler):
     def visit_pow(self, obj: Pow, **kw) -> str:
         attr = {**kw, "alias_clause": None}
         column = obj.column.compile(self.dialect, **attr).string
-        return ClauseInfo.concat_alias_and_column(f"POW({column}, {obj._exponent})", obj.alias)
+        return ClauseInfo.concat_clause_with_his_alias(f"POW({column}, {obj._exponent})", obj.alias)
 
     def visit_sqrt(self, obj: Sqrt, **kw) -> str:
         return self._compile_aggregate_method("SQRT", obj, **kw)
@@ -554,7 +552,7 @@ class MySQLCompiler(compiler.SQLCompiler):
     def visit_mod(self, obj: Mod, **kw) -> str:
         attr = {**kw, "alias_clause": None}
         column = obj.column.compile(self.dialect, **attr).string
-        return ClauseInfo.concat_alias_and_column(f"MOD({column}, {obj._divisor})", obj.alias)
+        return ClauseInfo.concat_clause_with_his_alias(f"MOD({column}, {obj._divisor})", obj.alias)
 
     def visit_rand(self, obj: Rand, **kw) -> str:
         return self._compile_aggregate_method("RAND", obj, **kw)
@@ -562,22 +560,24 @@ class MySQLCompiler(compiler.SQLCompiler):
     def visit_truncate(self, obj: Truncate, **kw) -> str:
         attr = {**kw, "alias_clause": None}
         column = obj.column.compile(self.dialect, **attr).string
-        return ClauseInfo.concat_alias_and_column(f"TRUNCATE({column}, {obj._decimal})", obj.alias)
+        return ClauseInfo.concat_clause_with_his_alias(f"TRUNCATE({column}, {obj._decimal})", obj.alias)
 
     def _compile_aggregate_method(self, name: str, function: IFunction, **kw) -> str:
         attr = {**kw, "alias_clause": None}
         column = function.column.compile(self.dialect, **attr).string
-        return ClauseInfo.concat_alias_and_column(f"{name}({column})", function.alias)
+        return ClauseInfo.concat_clause_with_his_alias(f"{name}({column})", function.alias)
 
     def visit_st_astext(self, st_astext: ST_AsText) -> str:
         # avoid use placeholder when using IFunction because no make sense.
         if st_astext.alias and (found := ClauseInfo._keyRegex.findall(st_astext.alias)):
             raise NotKeysInIFunctionError(found)
-        return ClauseInfo.concat_alias_and_column(f"ST_AsText({st_astext.column.compile(self.dialect, alias_clause=None).string})", st_astext.alias)
+        return ClauseInfo.concat_clause_with_his_alias(f"ST_AsText({st_astext.column.compile(self.dialect, alias_clause=None).string})", st_astext.alias)
 
     def visit_st_contains(self, st_contains: ST_Contains) -> str:
+        # FIXME [ ]: It's not working as expected. Should be something like
+        # ST_Contains(`table_type`.points, ST_GeomFromText(%s))
         attr1 = st_contains.column.compile(self.dialect, alias_clause=None).string
-        attr2 = ClauseInfo(None, st_contains.point, dialect=self.dialect).query(self.dialect, alias_clause=None)
+        attr2 = ClauseInfo(None, st_contains.point, dialect=self.dialect).query(self.dialect)
         return f"ST_Contains({attr1}, {attr2})"
 
 
@@ -602,7 +602,8 @@ class MySQLDDLCompiler(compiler.DDLCompiler):
         compare = fk.resolved_function()
         lcon = compare.left_condition
         rcon = compare.right_condition
-        return f"FOREIGN KEY ({lcon.column_name}) REFERENCES {rcon.table.__table_name__}({rcon.column_name})"
+        rdb = f"{ClauseInfo.wrapped_with_quotes(db)}." if (db := compare.right_condition.table.__db_name__) else ""
+        return f"FOREIGN KEY ({lcon.column_name}) REFERENCES {rdb}{rcon.table.__table_name__}({rcon.column_name})"
 
 
 class MySQLTypeCompiler(compiler.GenericTypeCompiler):
