@@ -21,16 +21,17 @@ class TypeEngine[T: Any](Element, abc.ABC):
     _type: ClassVar[T]
 
     @property
-    @abc.abstractmethod
-    def python_type(self) -> T: ...
+    def python_type(self) -> T:
+        # return object
+        return type(None)
 
     def _resolve_for_literal_value(self, value: T) -> TypeEngine[T]:
         return self
 
     @util.preload_module("ormlambda.sql.sqltypes")
     def coerce_compared_value[TType](self, value: TType) -> TypeEngine[TType]:
-        resolve_primitive_types = util.preloaded.sql_types.resolve_primitive_types
-        NULLTYPE = util.preloaded.sql_types.NULLTYPE
+        resolve_primitive_types = util.preloaded.sql_sqltypes.resolve_primitive_types
+        NULLTYPE = util.preloaded.sql_sqltypes.NULLTYPE
 
         _coerced_type = resolve_primitive_types(value)
         if _coerced_type is NULLTYPE:
@@ -39,3 +40,6 @@ class TypeEngine[T: Any](Element, abc.ABC):
 
     def __repr__(self):
         return f"{TypeEngine.__name__}: {super().__repr__()}"
+
+    def __str__(self):
+        return f"{type(self).__name__}"
\ No newline at end of file
