@@ -209,13 +209,15 @@ class IStatements[T: Table](Element):
     # endregion
     # region select
     @overload
-    def select(self, selector: Optional[Callable[[T], tuple]] = ..., *, only_query: bool = ..., **kwargs) -> str: ...
+    def select(self) -> tuple[T, ...]: ...
     @overload
     def select[T1](self, selector: Callable[[T], T1 | tuple[T1]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> tuple[T1, ...]: ...
     @overload
     def select[*T1](self, selector: Callable[[T], tuple[*T1]], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> Tuple[*T1]: ...
     @overload
     def select(self, *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> Tuple[T]: ...
+    @overload
+    def select(self, selector: Optional[Callable[[T], tuple]] = ..., *, only_query: bool = ...) -> str: ...
 
     # region deal with flavours
     @overload
@@ -243,7 +245,9 @@ class IStatements[T: Table](Element):
     # endregion
     # region select_one
     @overload
-    def select_one(self, selector: Optional[Callable[[T], Any]] = ..., *, only_query: bool = ..., **kwargs) -> str: ...
+    def select_one(self) -> T: ...
+    @overload
+    def select_one(self, selector: Optional[Callable[[T], Any]] = ..., *, only_query: bool = ...) -> str: ...
     @overload
     def select_one(self, *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ...) -> T: ...
     @overload
@@ -273,7 +277,9 @@ class IStatements[T: Table](Element):
 
     # region first
     @overload
-    def first(self, selector: Optional[Callable[[T], Any]] = ..., *, only_query: bool = ..., **kwargs) -> str: ...
+    def first(self) -> T: ...
+    @overload
+    def first(self, selector: Optional[Callable[[T], Any]] = ..., *, only_query: bool = ...) -> str: ...
     @overload
     def first(self, *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ..., only_query: bool = ...) -> T: ...
     @overload
@@ -286,6 +292,8 @@ class IStatements[T: Table](Element):
     def first[TFlavour](self, selector: Callable[[T], Any], *, by: JoinType = ..., alias: Optional[AliasType[ColumnType]] = ..., flavour: Type[TFlavour], avoid_duplicates: bool = ..., only_query: bool = ...) -> TFlavour: ...
     @overload
     def first(self, selector: Callable[[T], tuple], *, by: JoinType = ..., flavour: Type[dict], alias: Optional[AliasType[ColumnType]] = ..., avoid_duplicates: bool = ..., only_query: bool = ...) -> dict[str, Any]: ...
+    @overload
+    def first[TFlavour](self, flavour: TFlavour,**kw) -> TFlavour: ...
 
     @abstractmethod
     def first(
