@@ -22,12 +22,13 @@ if TYPE_CHECKING:
     sql_column_table_proxy = _sql_column_table_proxy
     sql_foreign_key = _sql_foreign_key
     sql_clause_info = _sql_clause_info
-    sql_types = _sql_sqltypes
+    sql_sqltypes = _sql_sqltypes
     sql_clauses = _sql_clauses
     sql_functions = _sql_functions
 
     sql_type_api = _sql_type_api
 
+
 class ModuleRegistry:
     """Registry of modules to load in a package init file.
 
